Mapping genetic values to fitness
======================================================================

.. autoclass:: fwdpy11.GeneticValueToFitnessMap

.. autoclass:: fwdpy11.MultivariateGeneticValueToFitnessMap

.. autoclass:: fwdpy11.GeneticValueIsTrait

.. autoclass:: fwdpy11.GeneticValueIsFitness

.. autoclass:: fwdpy11.GSS
    :members:

.. autoclass:: fwdpy11.GSSmo
    :members:

.. autoclass:: fwdpy11.MultivariateGSS
    :members:

.. autoclass:: fwdpy11.MultivariateGSSmo
    :members:




